summaryrefslogtreecommitdiff
path: root/print
diff options
context:
space:
mode:
authorkhorben <khorben@pkgsrc.org>2021-11-08 00:56:35 +0000
committerkhorben <khorben@pkgsrc.org>2021-11-08 00:56:35 +0000
commitcea74939b2299bd0df7b5b421eae2025468c1391 (patch)
tree881833db45facfb54aab9962e7900e8c758dc006 /print
parentad10356353658529a4b41202a46c34c9d2f41816 (diff)
downloadpkgsrc-cea74939b2299bd0df7b5b421eae2025468c1391.tar.gz
cups-base: let the RC script work unprivileged
This takes advantage of the introduction of the SYSCONFBASE variable. Tested on NetBSD/amd64. Bumps PKGREVISION.
Diffstat (limited to 'print')
-rw-r--r--print/cups-base/Makefile4
-rw-r--r--print/cups-base/files/cupsd.sh10
2 files changed, 7 insertions, 7 deletions
diff --git a/print/cups-base/Makefile b/print/cups-base/Makefile
index cedb3f303e0..f5234fb5c20 100644
--- a/print/cups-base/Makefile
+++ b/print/cups-base/Makefile
@@ -1,6 +1,6 @@
-# $NetBSD: Makefile,v 1.44 2021/10/21 07:46:32 wiz Exp $
+# $NetBSD: Makefile,v 1.45 2021/11/08 00:56:35 khorben Exp $
-PKGREVISION= 3
+PKGREVISION= 4
.include "../../print/cups/Makefile.common"
PKGNAME= cups-base-${CUPS_VERS}
diff --git a/print/cups-base/files/cupsd.sh b/print/cups-base/files/cupsd.sh
index 9813c142009..0570189b017 100644
--- a/print/cups-base/files/cupsd.sh
+++ b/print/cups-base/files/cupsd.sh
@@ -1,13 +1,13 @@
#!@RCD_SCRIPTS_SHELL@
#
-# $NetBSD: cupsd.sh,v 1.1 2017/11/12 14:10:15 khorben Exp $
+# $NetBSD: cupsd.sh,v 1.2 2021/11/08 00:56:35 khorben Exp $
#
# Common UNIX Printing System daemon
#
# PROVIDE: cups
# REQUIRE: DAEMON
#
# You will need to set some variables in /etc/rc.conf to start cupsd:
#
# cupsd=YES
# cupsd_wait=YES # set to "YES" to wait for cupsd to detect printers;
@@ -16,8 +16,8 @@
# # to respond before we declare it not responding;
# # this variable is optional and defaults to "60".
-if [ -f /etc/rc.subr ]; then
- . /etc/rc.subr
+if [ -f @SYSCONFBASE@/rc.subr ]; then
+ . @SYSCONFBASE@/rc.subr
fi
name="cupsd"
@@ -63,7 +63,7 @@ cupsd_waitcmd()
fi
}
-if [ -f /etc/rc.subr ]; then
+if [ -f @SYSCONFBASE@/rc.subr ]; then
load_rc_config $name
: ${cupsd_wait:=NO}
: ${cupsd_timeout:=60}
@@ -1,13 +1,13 @@
# REQUIRE: DAEMON
#
-# You will need to set some variables in /etc/rc.conf to start cupsd:
+# You will need to set some variables in @SYSCONFBASE@/rc.conf to start cupsd:
#
# cupsd=YES